==> huaweicloudsdkaom-3.0.82-py2.py3-none-any.whl: huaweicloudsdkaom/v2/model/add_alarm_rule_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AddAlarmRuleResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'alarm_rule_id': 'int'
    }

    attribute_map = {
        'alarm_rule_id': 'alarm_rule_id'
    }

    def __init__(self, alarm_rule_id=None):
        """AddAlarmRuleResponse - a model defined in huaweicloud sdk"""
        
        super(AddAlarmRuleResponse, self).__init__()

        self._alarm_rule_id = None
        self.discriminator = None

        if alarm_rule_id is not None:
            self.alarm_rule_id = alarm_rule_id

    @property
    def alarm_rule_id(self):
        """Gets the alarm_rule_id of this AddAlarmRuleResponse.

        阈值规则id。

        :return: The alarm_rule_id of this AddAlarmRuleResponse.
        :rtype: int
        """
        return self._alarm_rule_id

    @alarm_rule_id.setter
    def alarm_rule_id(self, alarm_rule_id):
        """Sets the alarm_rule_id of this AddAlarmRuleResponse.

        阈值规则id。

        :param alarm_rule_id: The alarm_rule_id of this AddAlarmRuleResponse.
        :type: int
        """
        self._alarm_rule_id = alarm_rule_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddAlarmRuleResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkaom-3.0.100-py2.py3-none-any.whl: huaweicloudsdkaom/v2/model/add_alarm_rule_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AddAlarmRuleResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'alarm_rule_id': 'int'
    }

    attribute_map = {
        'alarm_rule_id': 'alarm_rule_id'
    }

    def __init__(self, alarm_rule_id=None):
        """AddAlarmRuleResponse

        The model defined in huaweicloud sdk

        :param alarm_rule_id: 阈值规则id。
        :type alarm_rule_id: int
        """
        
        super(AddAlarmRuleResponse, self).__init__()

        self._alarm_rule_id = None
        self.discriminator = None

        if alarm_rule_id is not None:
            self.alarm_rule_id = alarm_rule_id

    @property
    def alarm_rule_id(self):
        """Gets the alarm_rule_id of this AddAlarmRuleResponse.

        阈值规则id。

        :return: The alarm_rule_id of this AddAlarmRuleResponse.
        :rtype: int
        """
        return self._alarm_rule_id

    @alarm_rule_id.setter
    def alarm_rule_id(self, alarm_rule_id):
        """Sets the alarm_rule_id of this AddAlarmRuleResponse.

        阈值规则id。

        :param alarm_rule_id: The alarm_rule_id of this AddAlarmRuleResponse.
        :type alarm_rule_id: int
        """
        self._alarm_rule_id = alarm_rule_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddAlarmRuleResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
